@@ -10,6 +10,8 @@
 #include <Quotient/syncdata.h>
 #include <qnamespace.h>
 
+#include "utils.h"
+
 using namespace Quotient;
 
 class TestRoom : public NeoChatRoom
@@ -38,6 +40,7 @@ private Q_SLOTS:
     void stripDisallowedTags();
     void stripDisallowedAttributes();
     void emptyCodeTags();
+    void formatBlockQuote();
 
     void sendSimpleStringCase();
     void sendSingleParaMarkup();
@@ -64,6 +67,7 @@ private Q_SLOTS:
     void receiveRichEdited_data();
     void receiveRichEdited();
     void receiveLineSeparator();
+    void receiveRichCodeUrl();
 
     void linkPreviewsMatch_data();
     void linkPreviewsMatch();
@@ -76,131 +80,11 @@ void TextHandlerTest::initTestCase()
     connection = Connection::makeMockConnection(QStringLiteral("@bob:kde.org"));
     room = new TestRoom(connection, QStringLiteral("#myroom:kde.org"), JoinState::Join);
 
-    const auto json = QJsonDocument::fromJson(R"EVENT({
-  "account_data": {
-    "events": [
-      {
-        "content": {
-          "tags": {
-            "u.work": {
-              "order": 0.9
-            }
-          }
-        },
-        "type": "m.tag"
-      },
-      {
-        "content": {
-          "custom_config_key": "custom_config_value"
-        },
-        "type": "org.example.custom.room.config"
-      }
-    ]
-  },
-  "ephemeral": {
-    "events": [
-      {
-        "content": {
-          "user_ids": [
-            "@alice:matrix.org",
-            "@bob:example.com"
-          ]
-        },
-        "room_id": "!jEsUZKDJdhlrceRyVU:example.org",
-        "type": "m.typing"
-      }
-    ]
-  },
-  "state": {
-    "events": [
-      {
-        "content": {
-          "avatar_url": "mxc://example.org/SEsfnsuifSDFSSEF",
-          "displayname": "Alice Margatroid",
-          "membership": "join",
-          "reason": "Looking for support"
-        },
-        "event_id": "$143273582443PhrSn:example.org",
-        "origin_server_ts": 1432735824653,
-        "room_id": "!jEsUZKDJdhlrceRyVU:example.org",
-        "sender": "@example:example.org",
-        "state_key": "@alice:example.org",
-        "type": "m.room.member",
-        "unsigned": {
-          "age": 1234
-        }
-      }
-    ]
-  },
-  "summary": {
-    "m.heroes": [
-      "@alice:example.com",
-      "@bob:example.com"
-    ],
-    "m.invited_member_count": 0,
-    "m.joined_member_count": 2
-  },
-  "timeline": {
-    "events": [
-      {
-        "content": {
-          "body": "This is an **example** text message",
-          "format": "org.matrix.custom.html",
-          "formatted_body": "<b>This is an example text message</b>",
-          "msgtype": "m.text"
-        },
-        "event_id": "$143273582443PhrSn:example.org",
-        "origin_server_ts": 1432735824654,
-        "room_id": "!jEsUZKDJdhlrceRyVU:example.org",
-        "sender": "@example:example.org",
-        "type": "m.room.message",
-        "unsigned": {
-          "age": 1232
-        }
-      },
-      {
-        "content": {
-          "body": "/me This is an emote.",
-          "format": "org.matrix.custom.html",
-          "formatted_body": "This is an emote.",
-          "msgtype": "m.emote"
-        },
-        "event_id": "$153273582443PhrSn:example.org",
-        "origin_server_ts": 1532735824654,
-        "room_id": "!jEsUZKDJdhlrceRyVU:example.org",
-        "sender": "@example:example.org",
-        "type": "m.room.message",
-        "unsigned": {
-          "age": 1231
-        }
-      },
-      {
-        "content": {
-            "body": "tested",
-            "msgtype": "m.text"
-        },
-        "event_id": "$zrCiBxBnqqTn0Z5FY78qSZAszno_w8nJJXzfBULG-3E",
-        "origin_server_ts": 1680948575928,
-        "room_id": "!jEsUZKDJdhlrceRyVU:example.org",
-        "sender": "@example:example.org",
-        "type": "m.room.message",
-        "unsigned": {
-            "age": 1747776,
-            "m.relations": {
-                "m.replace": {
-                    "event_id": "$UX0PlpyI7vYO32iHMuuYEP7ECMh4sX3XLGiB2SwM4mQ",
-                    "origin_server_ts": 1680948580992,
-                    "sender": "@example:example.org"
-                }
-            }
-        }
-      }
-    ],
-    "limited": true,
-    "prev_batch": "t34-23535_0_0"
-  }
-})EVENT");
-    SyncRoomData roomData(QStringLiteral("@bob:kde.org"), JoinState::Join, json.object());
+    QFile testTextHandlerSyncFile;
+    testTextHandlerSyncFile.setFileName(QLatin1String(DATA_DIR) + u'/' + QLatin1String("test-texthandler-sync.json"));
+    testTextHandlerSyncFile.open(QIODevice::ReadOnly);
+    const auto testTextHandlerSyncJson = QJsonDocument::fromJson(testTextHandlerSyncFile.readAll());
+    SyncRoomData roomData(QStringLiteral("@bob:kde.org"), JoinState::Join, testTextHandlerSyncJson.object());
     room->update(std::move(roomData));
 }
 
@@ -263,6 +147,16 @@ void TextHandlerTest::emptyCodeTags()
     QCOMPARE(testTextHandler.handleRecieveRichText(), testOutputString);
 }
 
+void TextHandlerTest::formatBlockQuote()
+{
+    auto input = QStringLiteral("<blockquote>\n<p>Lorem Ispum</p>\n</blockquote>");
+    auto expectedOutput = QStringLiteral("<blockquote><table><tr><td>\u201CLorem Ispum\u201D</td></tr></table></blockquote>");
+
+    TextHandler testTextHandler;
+    testTextHandler.setData(input);
+    QCOMPARE(testTextHandler.handleRecieveRichText(), expectedOutput);
+}
+
 void TextHandlerTest::sendSimpleStringCase()
 {
     const QString testInputString = QStringLiteral("This data should just be put in a paragraph.");
@@ -361,6 +255,7 @@ void TextHandlerTest::receiveRichInPlainOut_data()
 
     QTest::newRow("ampersand") << QStringLiteral("a &amp; b") << QStringLiteral("a & b");
     QTest::newRow("quote") << QStringLiteral("&quot;a and b&quot;") << QStringLiteral("\"a and b\"");
+    QTest::newRow("new line") << QStringLiteral("new<br>line") << QStringLiteral("new\nline");
 }
 
 void TextHandlerTest::receiveRichInPlainOut()
@@ -555,10 +450,10 @@ void TextHandlerTest::receiveRichPlainUrl()
 void TextHandlerTest::receiveRichEmote()
 {
     auto event = room->messageEvents().at(1).get();
-    auto author = static_cast<NeoChatUser *>(room->user(event->senderId()));
+    auto author = room->user(event->senderId());
     const QString testInputString = QStringLiteral("This is an emote.");
-    const QString testOutputString = QStringLiteral("* <a href=\"https://matrix.to/#/@example:example.org\" style=\"color:") + author->color().name()
-        + QStringLiteral("\">@example:example.org</a> This is an emote.");
+    const QString testOutputString = QStringLiteral("* <a href=\"https://matrix.to/#/@example:example.org\" style=\"color:")
+        + Utils::getUserColor(author->hueF()).name() + QStringLiteral("\">@example:example.org</a> This is an emote.");
 
     TextHandler testTextHandler;
     testTextHandler.setData(testInputString);
@@ -574,8 +469,9 @@ void TextHandlerTest::receiveRichEdited_data()
     QTest::newRow("basic") << QStringLiteral("Edited") << QStringLiteral("Edited <span style=\"color:#000000\">(edited)</span>");
     QTest::newRow("multiple paragraphs") << QStringLiteral("<p>Edited</p>\n<p>Edited</p>")
                                          << QStringLiteral("<p>Edited</p>\n<p>Edited <span style=\"color:#000000\">(edited)</span></p>");
-    QTest::newRow("blockquote") << QStringLiteral("<blockquote>Edited</blockquote>")
-                                << QStringLiteral("<blockquote>Edited</blockquote><p> <span style=\"color:#000000\">(edited)</span></p>");
+    QTest::newRow("blockquote")
+        << QStringLiteral("<blockquote>Edited</blockquote>")
+        << QStringLiteral("<blockquote><table><tr><td>\u201CEdited\u201D</td></tr></table></blockquote><p> <span style=\"color:#000000\">(edited)</span></p>");
 }
 
 void TextHandlerTest::receiveRichEdited()
@@ -602,13 +498,13 @@ void TextHandlerTest::linkPreviewsMatch_data()
     QTest::addColumn<QString>("testInputString");
     QTest::addColumn<QList<QUrl>>("testOutputLinks");
 
-    QTest::newRow("plainHttps") << QStringLiteral("https://kde.org") << QList<QUrl>({QUrl("https://kde.org")});
-    QTest::newRow("richHttps") << QStringLiteral("<a href=\"https://kde.org\">Rich Link</a>") << QList<QUrl>({QUrl("https://kde.org")});
-    QTest::newRow("plainWww") << QStringLiteral("www.example.org") << QList<QUrl>({QUrl("www.example.org")});
+    QTest::newRow("plainHttps") << QStringLiteral("https://kde.org") << QList<QUrl>({QUrl("https://kde.org"_ls)});
+    QTest::newRow("richHttps") << QStringLiteral("<a href=\"https://kde.org\">Rich Link</a>") << QList<QUrl>({QUrl("https://kde.org"_ls)});
+    QTest::newRow("plainWww") << QStringLiteral("www.example.org") << QList<QUrl>({QUrl("www.example.org"_ls)});
     QTest::newRow("multipleHttps") << QStringLiteral("https://kde.org www.example.org")
                                    << QList<QUrl>({
-                                          QUrl("https://kde.org"),
-                                          QUrl("www.example.org"),
+                                          QUrl("https://kde.org"_ls),
+                                          QUrl("www.example.org"_ls),
                                       });
 }
 
@@ -644,5 +540,13 @@ void TextHandlerTest::linkPreviewsReject()
     QCOMPARE(testTextHandler.getLinkPreviews(), testOutputLinks);
 }
 
-QTEST_GUILESS_MAIN(TextHandlerTest)
+void TextHandlerTest::receiveRichCodeUrl()
+{
+    auto input = QStringLiteral("<code>https://kde.org</code>");
+    TextHandler testTextHandler;
+    testTextHandler.setData(input);
+    QCOMPARE(testTextHandler.handleRecieveRichText(), input);
+}
+
+QTEST_MAIN(TextHandlerTest)
 #include "texthandlertest.moc"
