@@ -42,6 +42,8 @@
 #include "trayicon_sni.h"
 #endif
 
+bool testMode = false;
+
 using namespace Quotient;
 
 Controller::Controller(QObject *parent)
@@ -56,9 +58,19 @@ Controller::Controller(QObject *parent)
     connect(NeoChatConfig::self(), &NeoChatConfig::SystemTrayChanged, this, &Controller::setQuitOnLastWindowClosed);
 #endif
 
-    QTimer::singleShot(0, this, [this] {
-        invokeLogin();
-    });
+    if (!testMode) {
+        QTimer::singleShot(0, this, [this] {
+            invokeLogin();
+        });
+    } else {
+        auto c = new NeoChatConnection(this);
+        c->assumeIdentity(QStringLiteral("@user:localhost:1234"), QStringLiteral("token_1234"));
+        connect(c, &Connection::connected, this, [c, this]() {
+            m_accountRegistry.add(c);
+            c->syncLoop();
+            Q_EMIT initiated();
+        });
+    }
 
     QObject::connect(QGuiApplication::instance(), &QCoreApplication::aboutToQuit, QGuiApplication::instance(), [this] {
         delete m_trayIcon;
@@ -93,12 +105,30 @@ Controller::Controller(QObject *parent)
     connect(&m_accountRegistry, &AccountRegistry::accountCountChanged, this, [this]() {
         if (m_accountRegistry.size() > oldAccountCount) {
             auto connection = dynamic_cast<NeoChatConnection *>(m_accountRegistry.accounts()[m_accountRegistry.size() - 1]);
-            connect(connection, &NeoChatConnection::syncDone, this, [connection]() {
+            connect(connection, &NeoChatConnection::syncDone, this, [this, connection]() {
                 NotificationsManager::instance().handleNotifications(connection);
             });
+            connectSingleShot(connection, &NeoChatConnection::syncDone, this, [this, connection] {
+                connection->setupPushNotifications(m_endpoint);
+            });
         }
         oldAccountCount = m_accountRegistry.size();
     });
+
+#ifdef HAVE_KUNIFIEDPUSH
+    auto connector = new KUnifiedPush::Connector(QStringLiteral("org.kde.neochat"));
+    connect(connector, &KUnifiedPush::Connector::endpointChanged, this, [this](const QString &endpoint) {
+        m_endpoint = endpoint;
+        for (auto &quotientConnection : m_accountRegistry) {
+            auto connection = dynamic_cast<NeoChatConnection *>(quotientConnection);
+            connection->setupPushNotifications(endpoint);
+        }
+    });
+
+    connector->registerClient(i18n("Receiving push notifications"));
+
+    m_endpoint = connector->endpoint();
+#endif
 }
 
 Controller &Controller::instance()
@@ -300,9 +330,6 @@ void Controller::setQuitOnLastWindowClosed()
             m_trayIcon = nullptr;
         }
     }
-    QGuiApplication::setQuitOnLastWindowClosed(!NeoChatConfig::self()->systemTray());
-#else
-    return;
 #endif
 }
 
@@ -326,20 +353,6 @@ void Controller::setActiveConnection(NeoChatConnection *connection)
     m_connection = connection;
     if (connection != nullptr) {
         NeoChatConfig::self()->setActiveConnection(connection->userId());
-        connect(connection, &NeoChatConnection::networkError, this, [this]() {
-            if (!m_isOnline) {
-                return;
-            }
-            m_isOnline = false;
-            Q_EMIT isOnlineChanged(false);
-        });
-        connect(connection, &NeoChatConnection::syncDone, this, [this] {
-            if (m_isOnline) {
-                return;
-            }
-            m_isOnline = true;
-            Q_EMIT isOnlineChanged(true);
-        });
         connect(connection, &NeoChatConnection::requestFailed, this, [](BaseJob *job) {
             if (dynamic_cast<DownloadFileJob *>(job) && job->jsonData()["errcode"_ls].toString() == "M_TOO_LARGE"_ls) {
                 RoomManager::instance().warning(i18n("File too large to download."), i18n("Contact your matrix server administrator for support."));
@@ -357,29 +370,25 @@ void Controller::saveWindowGeometry()
     WindowController::instance().saveGeometry();
 }
 
-bool Controller::isOnline() const
-{
-    return m_isOnline;
-}
-
-// TODO: Remove in favor of RoomManager::joinRoom
-void Controller::joinRoom(const QString &alias)
-{
-    if (!alias.contains(":"_ls)) {
-        Q_EMIT errorOccured(i18n("The room id you are trying to join is not valid"));
-        return;
-    }
-
-    const auto knownServer = alias.mid(alias.indexOf(":"_ls) + 1);
-    RoomManager::instance().joinRoom(m_connection, alias, QStringList{knownServer});
-}
-
 void Controller::forceRefreshTextDocument(QQuickTextDocument *textDocument, QQuickItem *item)
 {
     // HACK: Workaround bug QTBUG 93281
     connect(textDocument->textDocument(), SIGNAL(imagesLoaded()), item, SLOT(updateWholeDocument()));
 }
 
+void Controller::listenForNotifications()
+{
+#ifdef HAVE_KUNIFIEDPUSH
+    auto connector = new KUnifiedPush::Connector(QStringLiteral("org.kde.neochat"));
+
+    connect(connector, &KUnifiedPush::Connector::messageReceived, [](const QByteArray &data) {
+        NotificationsManager::instance().postPushNotification(data);
+    });
+
+    connector->registerClient(i18n("Receiving push notifications"));
+#endif
+}
+
 void Controller::setApplicationProxy()
 {
     NeoChatConfig *cfg = NeoChatConfig::self();
@@ -425,3 +434,8 @@ AccountRegistry &Controller::accounts()
 }
 
 #include "moc_controller.cpp"
+
+void Controller::setTestMode(bool test)
+{
+    testMode = test;
+}
