@@ -169,6 +169,28 @@ QString EventHandler::getAuthorDisplayName(bool isPending) const
     }
 }
 
+QString EventHandler::singleLineAuthorDisplayname(bool isPending) const
+{
+    if (m_room == nullptr) {
+        qCWarning(EventHandling) << "getAuthorDisplayName called with m_room set to nullptr.";
+        return {};
+    }
+    if (m_event == nullptr) {
+        qCWarning(EventHandling) << "getAuthorDisplayName called with m_event set to nullptr.";
+        return {};
+    }
+
+    const auto author = isPending ? m_room->localUser() : m_room->user(m_event->senderId());
+    auto displayName = m_room->htmlSafeMemberName(author->id());
+    displayName.replace(QStringLiteral("<br>\n"), QStringLiteral(" "));
+    displayName.replace(QStringLiteral("<br>"), QStringLiteral(" "));
+    displayName.replace(QStringLiteral("<br />\n"), QStringLiteral(" "));
+    displayName.replace(QStringLiteral("<br />"), QStringLiteral(" "));
+    displayName.replace(u'\n', QStringLiteral(" "));
+    displayName.replace(u'\u2028', QStringLiteral(" "));
+    return displayName;
+}
+
 QDateTime EventHandler::getTime(bool isPending, QDateTime lastUpdated) const
 {
     if (m_event == nullptr) {
@@ -663,12 +685,12 @@ QVariantMap EventHandler::getMediaInfoFromFileInfo(const EventContent::FileInfo
     QVariantMap mediaInfo;
 
     // Get the mxc URL for the media.
-    if (!fileInfo->url().isValid() || eventId.isEmpty()) {
+    if (!fileInfo->url().isValid() || fileInfo->url().scheme() != QStringLiteral("mxc") || eventId.isEmpty()) {
         mediaInfo["source"_ls] = QUrl();
     } else {
         QUrl source = m_room->makeMediaUrl(eventId, fileInfo->url());
 
-        if (source.isValid() && source.scheme() == QStringLiteral("mxc")) {
+        if (source.isValid()) {
             mediaInfo["source"_ls] = source;
         } else {
             mediaInfo["source"_ls] = QUrl();
