@@ -13,16 +13,16 @@
 
 using namespace Quotient;
 
-Login::Login(QObject *parent)
+LoginHelper::LoginHelper(QObject *parent)
     : QObject(parent)
 {
     init();
 }
 
-void Login::init()
+void LoginHelper::init()
 {
     m_homeserverReachable = false;
-    m_connection = new Connection();
+    m_connection = new NeoChatConnection();
     m_matrixId = QString();
     m_password = QString();
     m_deviceName = QStringLiteral("NeoChat %1 %2 %3 %4")
@@ -31,14 +31,14 @@ void Login::init()
     m_supportsPassword = false;
     m_ssoUrl = QUrl();
 
-    connect(this, &Login::matrixIdChanged, this, [this]() {
+    connect(this, &LoginHelper::matrixIdChanged, this, [this]() {
         setHomeserverReachable(false);
-        QRegularExpression validator("^\\@?[a-zA-Z0-9\\._=\\-/]+\\:[a-zA-Z0-9\\-]+(\\.[a-zA-Z0-9\\-]+)*(\\:[0-9]+)?$");
+        QRegularExpression validator(QStringLiteral("^\\@?[a-zA-Z0-9\\._=\\-/]+\\:[a-zA-Z0-9\\-]+(\\.[a-zA-Z0-9\\-]+)*(\\:[0-9]+)?$"));
         if (!validator.match(m_matrixId).hasMatch()) {
             return;
         }
 
-        if (m_matrixId == "@") {
+        if (m_matrixId == QLatin1Char('@')) {
             return;
         }
 
@@ -51,7 +51,7 @@ void Login::init()
         m_testing = true;
         Q_EMIT testingChanged();
         if (!m_connection) {
-            m_connection = new Connection();
+            m_connection = new NeoChatConnection();
         }
         m_connection->resolveServer(m_matrixId);
         connectSingleShot(m_connection, &Connection::loginFlowsChanged, this, [this]() {
@@ -87,7 +87,11 @@ void Login::init()
         Q_EMIT isLoggingInChanged();
     });
     connect(m_connection, &Connection::loginError, this, [this](QString error, const QString &) {
-        Q_EMIT errorOccured(i18n("Login Failed: %1", error));
+        if (error == QStringLiteral("Invalid username or password")) {
+            setInvalidPassword(true);
+        } else {
+            Q_EMIT errorOccured(i18n("Login Failed: %1", error));
+        }
         m_isLoggingIn = false;
         Q_EMIT isLoggingInChanged();
     });
@@ -96,85 +100,87 @@ void Login::init()
         Q_EMIT Controller::instance().globalErrorOccured(i18n("Network Error"), std::move(error));
     });
 
-    connectSingleShot(m_connection, &Connection::syncDone, this, []() {
+    connectSingleShot(m_connection, &Connection::syncDone, this, [this]() {
+        Q_EMIT loaded();
         Q_EMIT Controller::instance().initiated();
     });
 }
 
-void Login::setHomeserverReachable(bool reachable)
+void LoginHelper::setHomeserverReachable(bool reachable)
 {
     m_homeserverReachable = reachable;
     Q_EMIT homeserverReachableChanged();
 }
 
-bool Login::homeserverReachable() const
+bool LoginHelper::homeserverReachable() const
 {
     return m_homeserverReachable;
 }
 
-QString Login::matrixId() const
+QString LoginHelper::matrixId() const
 {
     return m_matrixId;
 }
 
-void Login::setMatrixId(const QString &matrixId)
+void LoginHelper::setMatrixId(const QString &matrixId)
 {
     m_matrixId = matrixId;
-    if (!m_matrixId.startsWith('@')) {
-        m_matrixId.prepend('@');
+    if (!m_matrixId.startsWith(QLatin1Char('@'))) {
+        m_matrixId.prepend(QLatin1Char('@'));
     }
     Q_EMIT matrixIdChanged();
 }
 
-QString Login::password() const
+QString LoginHelper::password() const
 {
     return m_password;
 }
 
-void Login::setPassword(const QString &password)
+void LoginHelper::setPassword(const QString &password)
 {
+    setInvalidPassword(false);
     m_password = password;
     Q_EMIT passwordChanged();
 }
 
-QString Login::deviceName() const
+QString LoginHelper::deviceName() const
 {
     return m_deviceName;
 }
 
-void Login::setDeviceName(const QString &deviceName)
+void LoginHelper::setDeviceName(const QString &deviceName)
 {
     m_deviceName = deviceName;
     Q_EMIT deviceNameChanged();
 }
 
-void Login::login()
+void LoginHelper::login()
 {
     m_isLoggingIn = true;
     Q_EMIT isLoggingInChanged();
 
     // Some servers do not have a .well_known file. So we login via the username part from the mxid,
     // rather than with the full mxid, as that would lead to an invalid user.
-    auto username = m_matrixId.mid(1, m_matrixId.indexOf(":") - 1);
+    auto username = m_matrixId.mid(1, m_matrixId.indexOf(QLatin1Char(':')) - 1);
     m_connection->loginWithPassword(username, m_password, m_deviceName, QString());
 }
 
-bool Login::supportsPassword() const
+bool LoginHelper::supportsPassword() const
 {
     return m_supportsPassword;
 }
 
-bool Login::supportsSso() const
+bool LoginHelper::supportsSso() const
 {
     return m_supportsSso;
 }
 
-QUrl Login::ssoUrl() const
+QUrl LoginHelper::ssoUrl() const
 {
     return m_ssoUrl;
 }
 
-void Login::loginWithSso()
+void LoginHelper::loginWithSso()
 {
     m_connection->resolveServer(m_matrixId);
     connectSingleShot(m_connection, &Connection::loginFlowsChanged, this, [this]() {
@@ -184,19 +190,30 @@ void Login::loginWithSso()
     });
 }
 
-bool Login::testing() const
+bool LoginHelper::testing() const
 {
     return m_testing;
 }
 
-bool Login::isLoggingIn() const
+bool LoginHelper::isLoggingIn() const
 {
     return m_isLoggingIn;
 }
 
-bool Login::isLoggedIn() const
+bool LoginHelper::isLoggedIn() const
 {
     return m_isLoggedIn;
 }
 
+void LoginHelper::setInvalidPassword(bool invalid)
+{
+    m_invalidPassword = invalid;
+    Q_EMIT isInvalidPasswordChanged();
+}
+
+bool LoginHelper::isInvalidPassword() const
+{
+    return m_invalidPassword;
+}
+
 #include "moc_login.cpp"
