@@ -4,21 +4,21 @@
 #pragma once
 
 #include <QObject>
+#include <QQmlEngine>
 #include <QUrl>
 
-namespace Quotient
-{
-class Connection;
-}
+class NeoChatConnection;
 
 /**
- * @class Login
+ * @class LoginHelper
  *
  * A helper class for logging into a Matrix account.
  */
-class Login : public QObject
+class LoginHelper : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
     /**
      * @brief Whether the home server for the account is reachable.
@@ -73,8 +73,23 @@ class Login : public QObject
      */
     Q_PROPERTY(bool isLoggedIn READ isLoggedIn NOTIFY isLoggedInChanged)
 
+    /**
+     * @brief Whether the password (or the username) is invalid.
+     */
+    Q_PROPERTY(bool isInvalidPassword READ isInvalidPassword NOTIFY isInvalidPasswordChanged)
+
 public:
-    explicit Login(QObject *parent = nullptr);
+    static LoginHelper &instance()
+    {
+        static LoginHelper _instance;
+        return _instance;
+    }
+
+    static LoginHelper *create(QQmlEngine *engine, QJSEngine *)
+    {
+        engine->setObjectOwnership(&instance(), QQmlEngine::CppOwnership);
+        return &instance();
+    }
 
     Q_INVOKABLE void init();
 
@@ -100,6 +115,9 @@ public:
 
     bool isLoggedIn() const;
 
+    bool isInvalidPassword() const;
+    void setInvalidPassword(bool invalid);
+
     Q_INVOKABLE void login();
     Q_INVOKABLE void loginWithSso();
 
@@ -116,6 +134,8 @@ Q_SIGNALS:
     void testingChanged();
     void isLoggingInChanged();
     void isLoggedInChanged();
+    void isInvalidPasswordChanged();
+    void loaded();
 
 private:
     void setHomeserverReachable(bool reachable);
@@ -126,9 +146,11 @@ private:
     QString m_deviceName;
     bool m_supportsSso = false;
     bool m_supportsPassword = false;
-    Quotient::Connection *m_connection = nullptr;
+    NeoChatConnection *m_connection = nullptr;
     QUrl m_ssoUrl;
     bool m_testing = false;
     bool m_isLoggingIn = false;
     bool m_isLoggedIn = false;
+    bool m_invalidPassword = false;
+    explicit LoginHelper(QObject *parent = nullptr);
 };
