@@ -171,6 +171,40 @@ int main(int argc, char *argv[])
         colorScheme.apply(NeoChatConfig::self()->colorScheme());
     }
 
+    QCommandLineParser parser;
+    parser.setApplicationDescription(i18n("Client for the matrix communication protocol"));
+    parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports matrix: url scheme"));
+    parser.addOption(QCommandLineOption("ignore-ssl-errors"_ls, i18n("Ignore all SSL Errors, e.g., unsigned certificates.")));
+
+    QCommandLineOption testOption("test"_ls, i18n("Only used for autotests"));
+    testOption.setFlags(QCommandLineOption::HiddenFromHelp);
+    parser.addOption(testOption);
+
+#ifdef HAVE_KUNIFIEDPUSH
+    QCommandLineOption dbusActivatedOption(QStringLiteral("dbus-activated"), i18n("Internal usage only."));
+    dbusActivatedOption.setFlags(QCommandLineOption::Flag::HiddenFromHelp);
+    parser.addOption(dbusActivatedOption);
+#endif
+
+    about.setupCommandLine(&parser);
+    parser.process(app);
+    about.processCommandLine(&parser);
+    Controller::setTestMode(parser.isSet("test"_ls));
+
+#ifdef HAVE_KUNIFIEDPUSH
+    if (parser.isSet(dbusActivatedOption)) {
+        // We want to be replaceable by the main client
+        KDBusService service(KDBusService::Replace);
+
+        Controller::listenForNotifications();
+        return QCoreApplication::exec();
+    }
+#endif
+
+#ifdef HAVE_KDBUSADDONS
+    KDBusService service(KDBusService::Unique);
+#endif
+
     qml_register_types_org_kde_neochat();
     qmlRegisterSingletonInstance("org.kde.neochat.config", 1, 0, "Config", NeoChatConfig::self());
     qmlRegisterSingletonInstance("org.kde.neochat.accounts", 1, 0, "AccountRegistry", &Controller::instance().accounts());
@@ -180,7 +214,6 @@ int main(int argc, char *argv[])
     QQmlApplicationEngine engine;
 
 #ifdef HAVE_KDBUSADDONS
-    KDBusService service(KDBusService::Unique);
     service.connect(&service,
                     &KDBusService::activateRequested,
                     &RoomManager::instance(),
@@ -199,7 +232,7 @@ int main(int argc, char *argv[])
                         auto args = arguments;
                         args.removeFirst();
                         for (const auto &arg : args) {
-                            RoomManager::instance().openResource(arg);
+                            RoomManager::instance().resolveResource(arg);
                         }
                     });
 #endif
@@ -208,15 +241,6 @@ int main(int argc, char *argv[])
     QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
     engine.setNetworkAccessManagerFactory(new NetworkAccessManagerFactory());
 
-    QCommandLineParser parser;
-    parser.setApplicationDescription(i18n("Client for the matrix communication protocol"));
-    parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports matrix: url scheme"));
-    parser.addOption(QCommandLineOption("ignore-ssl-errors"_ls, i18n("Ignore all SSL Errors, e.g., unsigned certificates.")));
-
-    about.setupCommandLine(&parser);
-    parser.process(app);
-    about.processCommandLine(&parser);
-
     if (parser.isSet("ignore-ssl-errors"_ls)) {
         QObject::connect(NetworkAccessManager::instance(), &QNetworkAccessManager::sslErrors, NetworkAccessManager::instance(), [](QNetworkReply *reply) {
             reply->ignoreSslErrors();
