@@ -4,6 +4,7 @@
 #include "devicesmodel.h"
 
 #include "controller.h"
+#include "jobs/neochatdeletedevicejob.h"
 
 #include <QDateTime>
 #include <QLocale>
@@ -23,8 +24,8 @@ DevicesModel::DevicesModel(QObject *parent)
 
 void DevicesModel::fetchDevices()
 {
-    if (Controller::instance().activeConnection()) {
-        auto job = Controller::instance().activeConnection()->callApi<GetDevicesJob>();
+    if (m_connection) {
+        auto job = m_connection->callApi<GetDevicesJob>();
         connect(job, &BaseJob::success, this, [this, job]() {
             beginResetModel();
             m_devices = job->devices();
@@ -65,7 +66,6 @@ QVariant DevicesModel::data(const QModelIndex &index, int role) const
         if (device.deviceId == m_connection->deviceId()) {
             return This;
         }
-#ifdef Quotient_E2EE_ENABLED
         if (!m_connection->isKnownE2eeCapableDevice(m_connection->userId(), device.deviceId)) {
             return Unencrypted;
         }
@@ -74,9 +74,6 @@ QVariant DevicesModel::data(const QModelIndex &index, int role) const
         } else {
             return Unverified;
         }
-#else
-        return Unverified;
-#endif
     }
     return {};
 }
@@ -105,7 +102,7 @@ void DevicesModel::logout(const QString &deviceId, const QString &password)
     for (index = 0; m_devices[index].deviceId != deviceId; index++)
         ;
 
-    auto job = Controller::instance().activeConnection()->callApi<NeochatDeleteDeviceJob>(m_devices[index].deviceId);
+    auto job = m_connection->callApi<NeochatDeleteDeviceJob>(m_devices[index].deviceId);
 
     connect(job, &BaseJob::result, this, [this, job, password, index] {
         auto onSuccess = [this, index]() {
@@ -117,12 +114,12 @@ void DevicesModel::logout(const QString &deviceId, const QString &password)
         if (job->error() != BaseJob::Success) {
             QJsonObject replyData = job->jsonData();
             QJsonObject authData;
-            authData["session"] = replyData["session"];
-            authData["password"] = password;
-            authData["type"] = "m.login.password";
-            QJsonObject identifier = {{"type", "m.id.user"}, {"user", Controller::instance().activeConnection()->user()->id()}};
-            authData["identifier"] = identifier;
-            auto *innerJob = Controller::instance().activeConnection()->callApi<NeochatDeleteDeviceJob>(m_devices[index].deviceId, authData);
+            authData["session"_ls] = replyData["session"_ls];
+            authData["password"_ls] = password;
+            authData["type"_ls] = "m.login.password"_ls;
+            QJsonObject identifier = {{"type"_ls, "m.id.user"_ls}, {"user"_ls, m_connection->user()->id()}};
+            authData["identifier"_ls] = identifier;
+            auto *innerJob = m_connection->callApi<NeochatDeleteDeviceJob>(m_devices[index].deviceId, authData);
             connect(innerJob, &BaseJob::success, this, onSuccess);
         } else {
             onSuccess();
@@ -135,7 +132,7 @@ void DevicesModel::setName(const QString &deviceId, const QString &name)
     int index;
     for (index = 0; m_devices[index].deviceId != deviceId; index++);
 
-    auto job = Controller::instance().activeConnection()->callApi<UpdateDeviceJob>(m_devices[index].deviceId, name);
+    auto job = m_connection->callApi<UpdateDeviceJob>(m_devices[index].deviceId, name);
     QString oldName = m_devices[index].displayName;
     beginResetModel();
     m_devices[index].displayName = name;
@@ -161,17 +158,15 @@ void DevicesModel::setConnection(Connection *connection)
     Q_EMIT connectionChanged();
     fetchDevices();
 
-#ifdef Quotient_E2EE_ENABLED
     connect(m_connection, &Connection::sessionVerified, this, [this](const QString &userId, const QString &deviceId) {
         Q_UNUSED(deviceId);
-        if (userId == Controller::instance().activeConnection()->userId()) {
+        if (userId == m_connection->userId()) {
             fetchDevices();
         }
     });
     connect(m_connection, &Connection::finishedQueryingKeys, this, [this]() {
         fetchDevices();
     });
-#endif
 }
 
 #include "moc_devicesmodel.cpp"
