@@ -71,9 +71,6 @@ QHash<int, QByteArray> MessageEventModel::roleNames() const
 MessageEventModel::MessageEventModel(QObject *parent)
     : QAbstractListModel(parent)
 {
-    connect(static_cast<QGuiApplication *>(QGuiApplication::instance()), &QGuiApplication::paletteChanged, this, [this] {
-        Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0), {AuthorRole, ReplyAuthor, ReadMarkersRole});
-    });
 }
 
 NeoChatRoom *MessageEventModel::room() const
@@ -392,13 +389,7 @@ int MessageEventModel::rowCount(const QModelIndex &parent) const
         return 0;
     }
 
-    const auto firstIt = m_currentRoom->messageEvents().crbegin();
-    if (firstIt != m_currentRoom->messageEvents().crend()) {
-        const auto &firstEvt = **firstIt;
-        return m_currentRoom->timelineSize() + (lastReadEventId != firstEvt.id() ? 1 : 0);
-    } else {
-        return m_currentRoom->timelineSize();
-    }
+    return int(m_currentRoom->pendingEvents().size()) + m_currentRoom->timelineSize() + (m_lastReadEventIndex.isValid() ? 1 : 0);
 }
 
 bool MessageEventModel::canFetchMore(const QModelIndex &parent) const
@@ -425,7 +416,7 @@ QVariant MessageEventModel::data(const QModelIndex &idx, int role) const
     }
     const auto row = idx.row();
 
-    if (!m_currentRoom || row < 0 || row >= int(m_currentRoom->pendingEvents().size()) + m_currentRoom->timelineSize()) {
+    if (!m_currentRoom || row < 0 || row >= rowCount()) {
         return {};
     };
 
@@ -440,6 +431,15 @@ QVariant MessageEventModel::data(const QModelIndex &idx, int role) const
             const KFormat format;
             return format.formatRelativeDateTime(eventDate, QLocale::ShortFormat);
         }
+        case SpecialMarksRole:
+            // Check if all the earlier events in the timeline are hidden. If so hide this.
+            for (auto r = row - 1; r >= 0; --r) {
+                const auto specialMark = index(r).data(SpecialMarksRole);
+                if (!(specialMark == EventStatus::Hidden || specialMark == EventStatus::Replaced)) {
+                    return EventStatus::Normal;
+                }
+            }
+            return EventStatus::Hidden;
         }
         return {};
     }
@@ -459,7 +459,6 @@ QVariant MessageEventModel::data(const QModelIndex &idx, int role) const
             return (reason.isEmpty()) ? i18n("<i>[This message was deleted]</i>")
                                       : i18n("<i>[This message was deleted: %1]</i>", evt.redactedBecause()->reason());
         }
-
         return eventHandler.getRichBody();
     }
 
@@ -726,4 +725,12 @@ void MessageEventModel::createEventObjects(const Quotient::RoomMessageEvent *eve
     }
 }
 
+bool MessageEventModel::event(QEvent *event)
+{
+    if (event->type() == QEvent::ApplicationPaletteChange) {
+        Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0), {AuthorRole, ReplyAuthor, ReadMarkersRole});
+    }
+    return QObject::event(event);
+}
+
 #include "moc_messageeventmodel.cpp"
