@@ -5,6 +5,7 @@
 
 #include <QAbstractListModel>
 #include <QObject>
+#include <QQmlEngine>
 
 #include <Quotient/csapi/users.h>
 
@@ -26,6 +27,7 @@ class Connection;
 class UserDirectoryListModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
 
     /**
      * @brief The current connection that the model is getting users from.
@@ -101,7 +103,7 @@ private:
 
     bool attempted = false;
 
-    QVector<Quotient::SearchUserDirectoryJob::User> users;
+    QList<Quotient::SearchUserDirectoryJob::User> users;
 
     Quotient::SearchUserDirectoryJob *job = nullptr;
 };
