@@ -6,6 +6,7 @@
 #include <QObject>
 #include <QQmlEngine>
 
+#include <QCoroTask>
 #include <Quotient/connection.h>
 
 class NeoChatConnection : public Quotient::Connection
@@ -26,6 +27,11 @@ class NeoChatConnection : public Quotient::Connection
     Q_PROPERTY(QString deviceKey READ deviceKey CONSTANT)
     Q_PROPERTY(QString encryptionKey READ encryptionKey CONSTANT)
 
+    /**
+     * @brief Whether NeoChat is currently able to connect to the server.
+     */
+    Q_PROPERTY(bool isOnline READ isOnline WRITE setIsOnline NOTIFY isOnlineChanged)
+
 public:
     NeoChatConnection(QObject *parent = nullptr);
     NeoChatConnection(const QUrl &server, QObject *parent = nullptr);
@@ -70,9 +76,20 @@ public:
      */
     Q_INVOKABLE void openOrCreateDirectChat(Quotient::User *user);
 
+    // note: this is intentionally a copied QString because
+    // the reference could be destroyed before the task is finished
+    QCoro::Task<void> setupPushNotifications(QString endpoint);
+
     QString deviceKey() const;
     QString encryptionKey() const;
 
+    bool isOnline() const;
+
 Q_SIGNALS:
     void labelChanged();
+    void isOnlineChanged();
+
+private:
+    bool m_isOnline = true;
+    void setIsOnline(bool isOnline);
 };
