@@ -8,8 +8,10 @@
 #include "controller.h"
 #include "enums/delegatetype.h"
 #include "models/messageeventmodel.h"
+#include "models/timelinemodel.h"
 #include "neochatconfig.h"
 #include "neochatroom.h"
+
 #include <KLocalizedString>
 #include <QDesktopServices>
 #include <QQuickTextDocument>
@@ -29,14 +31,14 @@ RoomManager::RoomManager(QObject *parent)
     , m_currentRoom(nullptr)
     , m_lastCurrentRoom(nullptr)
     , m_config(KSharedConfig::openStateConfig())
-    , m_messageEventModel(new MessageEventModel(this))
-    , m_messageFilterModel(new MessageFilterModel(this, m_messageEventModel))
+    , m_timelineModel(new TimelineModel(this))
+    , m_messageFilterModel(new MessageFilterModel(this, m_timelineModel))
     , m_mediaMessageFilterModel(new MediaMessageFilterModel(this, m_messageFilterModel))
 {
     m_lastRoomConfig = m_config->group(QStringLiteral("LastOpenRoom"));
 
     connect(this, &RoomManager::currentRoomChanged, this, [this]() {
-        m_messageEventModel->setRoom(m_currentRoom);
+        m_timelineModel->setRoom(m_currentRoom);
     });
 }
 
@@ -55,9 +57,9 @@ NeoChatRoom *RoomManager::currentRoom() const
     return m_currentRoom;
 }
 
-MessageEventModel *RoomManager::messageEventModel() const
+TimelineModel *RoomManager::timelineModel() const
 {
-    return m_messageEventModel;
+    return m_timelineModel;
 }
 
 MessageFilterModel *RoomManager::messageFilterModel() const
@@ -70,7 +72,12 @@ MediaMessageFilterModel *RoomManager::mediaMessageFilterModel() const
     return m_mediaMessageFilterModel;
 }
 
-void RoomManager::openResource(const QString &idOrUri, const QString &action)
+UriResolveResult RoomManager::resolveResource(const Uri &uri)
+{
+    return UriResolverBase::visitResource(m_connection, uri);
+}
+
+void RoomManager::resolveResource(const QString &idOrUri, const QString &action)
 {
     Uri uri{idOrUri};
     if (!uri.isValid()) {
@@ -93,6 +100,12 @@ void RoomManager::openResource(const QString &idOrUri, const QString &action)
         Q_EMIT warning(i18n("Room not found"), i18n("There's no room %1 in the room list. Check the spelling and the account.", idOrUri));
     } else { // Invalid cases should have been eliminated earlier
         Q_ASSERT(result == Quotient::UriResolved);
+
+        if (uri.type() == Uri::RoomAlias || uri.type() == Uri::RoomId) {
+            connectSingleShot(m_connection, &Connection::newRoom, this, [this, uri](Room *room) {
+                enterRoom(dynamic_cast<NeoChatRoom *>(room));
+            });
+        }
     }
 }
 
@@ -147,7 +160,7 @@ void RoomManager::loadInitialRoom()
     Q_ASSERT(m_connection);
 
     if (!m_arg.isEmpty()) {
-        openResource(m_arg);
+        resolveResource(m_arg);
     }
 
     if (m_currentRoom) {
